# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.predict.predict_eval import predict_eval_api_service_pb2 as cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2


class PredictEvalServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get = channel.unary_unary(
        '/ai.cogneed.api.predict.predicteval.PredictEvalService/get',
        request_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetResponse.FromString,
        )
    self.set = channel.unary_unary(
        '/ai.cogneed.api.predict.predicteval.PredictEvalService/set',
        request_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetResponse.FromString,
        )


class PredictEvalServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def set(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_PredictEvalServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get': grpc.unary_unary_rpc_method_handler(
          servicer.get,
          request_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetRequest.FromString,
          response_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.GetResponse.SerializeToString,
      ),
      'set': grpc.unary_unary_rpc_method_handler(
          servicer.set,
          request_deserializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetRequest.FromString,
          response_serializer=cogneed__protos_dot_predict_dot_predict__eval_dot_predict__eval__api__service__pb2.SetResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.predict.predicteval.PredictEvalService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/audio-web-middleware/audio-web-middleware-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import common_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/audio-web-middleware/audio-web-middleware-service.proto',
  package='ai.cogneed.api.audio.web',
  syntax='proto3',
  serialized_options=_b('\n\030ai.cogneed.api.audio.webP\001'),
  serialized_pb=_b('\nScogneed-protos/audio-stream/audio-web-middleware/audio-web-middleware-service.proto\x12\x18\x61i.cogneed.api.audio.web\x1a/cogneed-protos/audio-stream/common/common.proto\"M\n\x0eStatusResponse\x12;\n\x0bstatus_code\x18\x01 \x01(\x0e\x32&.ai.cogneed.cloud.speech.v1.StatusCode\")\n\x11\x45ndSessionRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"(\n\x10SubscribeRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"8\n\x0fWebAudioRequest\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12\x14\n\x0csession_uuid\x18\x02 \x01(\t\"&\n\x0eUnstackRequest\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\"T\n\x0fUnstackResponse\x12\x41\n\ndetections\x18\x01 \x03(\x0b\x32-.ai.cogneed.cloud.speech.v1.DetectionResponse\"\x8a\x01\n\x16StartWebSessionRequest\x12\x37\n\tuser_info\x18\x01 \x01(\x0b\x32$.ai.cogneed.cloud.speech.v1.UserInfo\x12\x37\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\'.ai.cogneed.cloud.speech.v1.AudioFormat\"R\n\x17StartWebSessionResponse\x12\x13\n\tcall_uuid\x18\x01 \x01(\tH\x00\x12\x17\n\rmessage_error\x18\x02 \x01(\tH\x00\x42\t\n\x07\x63ontent2\xa7\x03\n\x0fWebAudioService\x12l\n\x05start\x12\x30.ai.cogneed.api.audio.web.StartWebSessionRequest\x1a\x31.ai.cogneed.api.audio.web.StartWebSessionResponse\x12\\\n\x05\x61udio\x12).ai.cogneed.api.audio.web.WebAudioRequest\x1a(.ai.cogneed.api.audio.web.StatusResponse\x12h\n\tsubscribe\x12*.ai.cogneed.api.audio.web.SubscribeRequest\x1a-.ai.cogneed.cloud.speech.v1.DetectionResponse0\x01\x12^\n\x07unstack\x12(.ai.cogneed.api.audio.web.UnstackRequest\x1a).ai.cogneed.api.audio.web.UnstackResponseB\x1c\n\x18\x61i.cogneed.api.audio.webP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.DESCRIPTOR,])




_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='ai.cogneed.api.audio.web.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code', full_name='ai.cogneed.api.audio.web.StatusResponse.status_code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=239,
)


_ENDSESSIONREQUEST = _descriptor.Descriptor(
  name='EndSessionRequest',
  full_name='ai.cogneed.api.audio.web.EndSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.EndSessionRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=282,
)


_SUBSCRIBEREQUEST = _descriptor.Descriptor(
  name='SubscribeRequest',
  full_name='ai.cogneed.api.audio.web.SubscribeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.SubscribeRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=284,
  serialized_end=324,
)


_WEBAUDIOREQUEST = _descriptor.Descriptor(
  name='WebAudioRequest',
  full_name='ai.cogneed.api.audio.web.WebAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.audio.web.WebAudioRequest.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.WebAudioRequest.session_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=382,
)


_UNSTACKREQUEST = _descriptor.Descriptor(
  name='UnstackRequest',
  full_name='ai.cogneed.api.audio.web.UnstackRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='ai.cogneed.api.audio.web.UnstackRequest.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=422,
)


_UNSTACKRESPONSE = _descriptor.Descriptor(
  name='UnstackResponse',
  full_name='ai.cogneed.api.audio.web.UnstackResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='detections', full_name='ai.cogneed.api.audio.web.UnstackResponse.detections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=508,
)


_STARTWEBSESSIONREQUEST = _descriptor.Descriptor(
  name='StartWebSessionRequest',
  full_name='ai.cogneed.api.audio.web.StartWebSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_info', full_name='ai.cogneed.api.audio.web.StartWebSessionRequest.user_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format', full_name='ai.cogneed.api.audio.web.StartWebSessionRequest.format', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=649,
)


_STARTWEBSESSIONRESPONSE = _descriptor.Descriptor(
  name='StartWebSessionResponse',
  full_name='ai.cogneed.api.audio.web.StartWebSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.audio.web.StartWebSessionResponse.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_error', full_name='ai.cogneed.api.audio.web.StartWebSessionResponse.message_error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.audio.web.StartWebSessionResponse.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=651,
  serialized_end=733,
)

_STATUSRESPONSE.fields_by_name['status_code'].enum_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._STATUSCODE
_UNSTACKRESPONSE.fields_by_name['detections'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._DETECTIONRESPONSE
_STARTWEBSESSIONREQUEST.fields_by_name['user_info'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._USERINFO
_STARTWEBSESSIONREQUEST.fields_by_name['format'].message_type = cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._AUDIOFORMAT
_STARTWEBSESSIONRESPONSE.oneofs_by_name['content'].fields.append(
  _STARTWEBSESSIONRESPONSE.fields_by_name['call_uuid'])
_STARTWEBSESSIONRESPONSE.fields_by_name['call_uuid'].containing_oneof = _STARTWEBSESSIONRESPONSE.oneofs_by_name['content']
_STARTWEBSESSIONRESPONSE.oneofs_by_name['content'].fields.append(
  _STARTWEBSESSIONRESPONSE.fields_by_name['message_error'])
_STARTWEBSESSIONRESPONSE.fields_by_name['message_error'].containing_oneof = _STARTWEBSESSIONRESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
DESCRIPTOR.message_types_by_name['EndSessionRequest'] = _ENDSESSIONREQUEST
DESCRIPTOR.message_types_by_name['SubscribeRequest'] = _SUBSCRIBEREQUEST
DESCRIPTOR.message_types_by_name['WebAudioRequest'] = _WEBAUDIOREQUEST
DESCRIPTOR.message_types_by_name['UnstackRequest'] = _UNSTACKREQUEST
DESCRIPTOR.message_types_by_name['UnstackResponse'] = _UNSTACKRESPONSE
DESCRIPTOR.message_types_by_name['StartWebSessionRequest'] = _STARTWEBSESSIONREQUEST
DESCRIPTOR.message_types_by_name['StartWebSessionResponse'] = _STARTWEBSESSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), dict(
  DESCRIPTOR = _STATUSRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.StatusResponse)
  ))
_sym_db.RegisterMessage(StatusResponse)

EndSessionRequest = _reflection.GeneratedProtocolMessageType('EndSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENDSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.EndSessionRequest)
  ))
_sym_db.RegisterMessage(EndSessionRequest)

SubscribeRequest = _reflection.GeneratedProtocolMessageType('SubscribeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.SubscribeRequest)
  ))
_sym_db.RegisterMessage(SubscribeRequest)

WebAudioRequest = _reflection.GeneratedProtocolMessageType('WebAudioRequest', (_message.Message,), dict(
  DESCRIPTOR = _WEBAUDIOREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.WebAudioRequest)
  ))
_sym_db.RegisterMessage(WebAudioRequest)

UnstackRequest = _reflection.GeneratedProtocolMessageType('UnstackRequest', (_message.Message,), dict(
  DESCRIPTOR = _UNSTACKREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.UnstackRequest)
  ))
_sym_db.RegisterMessage(UnstackRequest)

UnstackResponse = _reflection.GeneratedProtocolMessageType('UnstackResponse', (_message.Message,), dict(
  DESCRIPTOR = _UNSTACKRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.UnstackResponse)
  ))
_sym_db.RegisterMessage(UnstackResponse)

StartWebSessionRequest = _reflection.GeneratedProtocolMessageType('StartWebSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _STARTWEBSESSIONREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.StartWebSessionRequest)
  ))
_sym_db.RegisterMessage(StartWebSessionRequest)

StartWebSessionResponse = _reflection.GeneratedProtocolMessageType('StartWebSessionResponse', (_message.Message,), dict(
  DESCRIPTOR = _STARTWEBSESSIONRESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_web_middleware.audio_web_middleware_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.audio.web.StartWebSessionResponse)
  ))
_sym_db.RegisterMessage(StartWebSessionResponse)


DESCRIPTOR._options = None

_WEBAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='WebAudioService',
  full_name='ai.cogneed.api.audio.web.WebAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=736,
  serialized_end=1159,
  methods=[
  _descriptor.MethodDescriptor(
    name='start',
    full_name='ai.cogneed.api.audio.web.WebAudioService.start',
    index=0,
    containing_service=None,
    input_type=_STARTWEBSESSIONREQUEST,
    output_type=_STARTWEBSESSIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='audio',
    full_name='ai.cogneed.api.audio.web.WebAudioService.audio',
    index=1,
    containing_service=None,
    input_type=_WEBAUDIOREQUEST,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='subscribe',
    full_name='ai.cogneed.api.audio.web.WebAudioService.subscribe',
    index=2,
    containing_service=None,
    input_type=_SUBSCRIBEREQUEST,
    output_type=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2._DETECTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='unstack',
    full_name='ai.cogneed.api.audio.web.WebAudioService.unstack',
    index=3,
    containing_service=None,
    input_type=_UNSTACKREQUEST,
    output_type=_UNSTACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_WEBAUDIOSERVICE)

DESCRIPTOR.services_by_name['WebAudioService'] = _WEBAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/audio-stream-recorder/audio-stream-recorder-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/audio-stream-recorder/audio-stream-recorder-service.proto',
  package='ai.cogneed.record.v1',
  syntax='proto3',
  serialized_options=_b('\n\024ai.cogneed.record.v1P\001'),
  serialized_pb=_b('\nUcogneed-protos/audio-stream/audio-stream-recorder/audio-stream-recorder-service.proto\x12\x14\x61i.cogneed.record.v1\"B\n\rRecordRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"\"\n\x12\x43onsolidateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x1a\n\x08Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x32\xb7\x01\n\rRecordService\x12M\n\x06record\x12#.ai.cogneed.record.v1.RecordRequest\x1a\x1e.ai.cogneed.record.v1.Response\x12W\n\x0b\x63onsolidate\x12(.ai.cogneed.record.v1.ConsolidateRequest\x1a\x1e.ai.cogneed.record.v1.ResponseB\x18\n\x14\x61i.cogneed.record.v1P\x01\x62\x06proto3')
)




_RECORDREQUEST = _descriptor.Descriptor(
  name='RecordRequest',
  full_name='ai.cogneed.record.v1.RecordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.record.v1.RecordRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.record.v1.RecordRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.record.v1.RecordRequest.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=177,
)


_CONSOLIDATEREQUEST = _descriptor.Descriptor(
  name='ConsolidateRequest',
  full_name='ai.cogneed.record.v1.ConsolidateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.record.v1.ConsolidateRequest.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=213,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='ai.cogneed.record.v1.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='ai.cogneed.record.v1.Response.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=241,
)

DESCRIPTOR.message_types_by_name['RecordRequest'] = _RECORDREQUEST
DESCRIPTOR.message_types_by_name['ConsolidateRequest'] = _CONSOLIDATEREQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecordRequest = _reflection.GeneratedProtocolMessageType('RecordRequest', (_message.Message,), dict(
  DESCRIPTOR = _RECORDREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_recorder.audio_stream_recorder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.record.v1.RecordRequest)
  ))
_sym_db.RegisterMessage(RecordRequest)

ConsolidateRequest = _reflection.GeneratedProtocolMessageType('ConsolidateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CONSOLIDATEREQUEST,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_recorder.audio_stream_recorder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.record.v1.ConsolidateRequest)
  ))
_sym_db.RegisterMessage(ConsolidateRequest)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'cogneed_protos.audio_stream.audio_stream_recorder.audio_stream_recorder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.record.v1.Response)
  ))
_sym_db.RegisterMessage(Response)


DESCRIPTOR._options = None

_RECORDSERVICE = _descriptor.ServiceDescriptor(
  name='RecordService',
  full_name='ai.cogneed.record.v1.RecordService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=244,
  serialized_end=427,
  methods=[
  _descriptor.MethodDescriptor(
    name='record',
    full_name='ai.cogneed.record.v1.RecordService.record',
    index=0,
    containing_service=None,
    input_type=_RECORDREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='consolidate',
    full_name='ai.cogneed.record.v1.RecordService.consolidate',
    index=1,
    containing_service=None,
    input_type=_CONSOLIDATEREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECORDSERVICE)

DESCRIPTOR.services_by_name['RecordService'] = _RECORDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/public/audio/audio_api.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/public/audio/audio_api.proto',
  package='ai.cogneed.audio.api',
  syntax='proto3',
  serialized_options=_b('\n\024ai.cogneed.audio.apiP\001'),
  serialized_pb=_b('\n+cogneed-protos/public/audio/audio_api.proto\x12\x14\x61i.cogneed.audio.api\"<\n\tAudioInfo\x12/\n\x05\x63odec\x18\x01 \x01(\x0e\x32 .ai.cogneed.audio.api.AudioCodec\"#\n\x11PersistenceConfig\x12\x0e\n\x06record\x18\x01 \x01(\x08\"(\n\x08UserInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08use_case\x18\x02 \x01(\t\"\xc1\x01\n\x12InitSessionRequest\x12\x31\n\tuser_info\x18\x01 \x01(\x0b\x32\x1e.ai.cogneed.audio.api.UserInfo\x12\x33\n\naudio_info\x18\x02 \x01(\x0b\x32\x1f.ai.cogneed.audio.api.AudioInfo\x12\x43\n\x12persistence_config\x18\x03 \x01(\x0b\x32\'.ai.cogneed.audio.api.PersistenceConfig\"\x1c\n\tAudioBlob\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\x8b\x01\n\x12\x41udioDetectRequest\x12\x38\n\x04init\x18\x01 \x01(\x0b\x32(.ai.cogneed.audio.api.InitSessionRequestH\x00\x12\x30\n\x05\x61udio\x18\x02 \x01(\x0b\x32\x1f.ai.cogneed.audio.api.AudioBlobH\x00\x42\t\n\x07request\"9\n\x11\x44\x65tectionResponse\x12\x13\n\x0bmillisecond\x18\x01 \x01(\x03\x12\x0f\n\x07keyword\x18\x02 \x01(\t**\n\nAudioCodec\x12\r\n\tG711_ULAW\x10\x00\x12\r\n\tG711_ALAW\x10\x01\x32{\n\x12StreamAudioService\x12\x65\n\x0cstream_audio\x12(.ai.cogneed.audio.api.AudioDetectRequest\x1a\'.ai.cogneed.audio.api.DetectionResponse(\x01\x30\x01\x42\x18\n\x14\x61i.cogneed.audio.apiP\x01\x62\x06proto3')
)

_AUDIOCODEC = _descriptor.EnumDescriptor(
  name='AudioCodec',
  full_name='ai.cogneed.audio.api.AudioCodec',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='G711_ULAW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G711_ALAW', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=637,
  serialized_end=679,
)
_sym_db.RegisterEnumDescriptor(_AUDIOCODEC)

AudioCodec = enum_type_wrapper.EnumTypeWrapper(_AUDIOCODEC)
G711_ULAW = 0
G711_ALAW = 1



_AUDIOINFO = _descriptor.Descriptor(
  name='AudioInfo',
  full_name='ai.cogneed.audio.api.AudioInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.audio.api.AudioInfo.codec', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=129,
)


_PERSISTENCECONFIG = _descriptor.Descriptor(
  name='PersistenceConfig',
  full_name='ai.cogneed.audio.api.PersistenceConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='ai.cogneed.audio.api.PersistenceConfig.record', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=166,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='ai.cogneed.audio.api.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ai.cogneed.audio.api.UserInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.audio.api.UserInfo.use_case', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=168,
  serialized_end=208,
)


_INITSESSIONREQUEST = _descriptor.Descriptor(
  name='InitSessionRequest',
  full_name='ai.cogneed.audio.api.InitSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_info', full_name='ai.cogneed.audio.api.InitSessionRequest.user_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio_info', full_name='ai.cogneed.audio.api.InitSessionRequest.audio_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistence_config', full_name='ai.cogneed.audio.api.InitSessionRequest.persistence_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=404,
)


_AUDIOBLOB = _descriptor.Descriptor(
  name='AudioBlob',
  full_name='ai.cogneed.audio.api.AudioBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.audio.api.AudioBlob.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=434,
)


_AUDIODETECTREQUEST = _descriptor.Descriptor(
  name='AudioDetectRequest',
  full_name='ai.cogneed.audio.api.AudioDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='init', full_name='ai.cogneed.audio.api.AudioDetectRequest.init', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='audio', full_name='ai.cogneed.audio.api.AudioDetectRequest.audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='ai.cogneed.audio.api.AudioDetectRequest.request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=437,
  serialized_end=576,
)


_DETECTIONRESPONSE = _descriptor.Descriptor(
  name='DetectionResponse',
  full_name='ai.cogneed.audio.api.DetectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='millisecond', full_name='ai.cogneed.audio.api.DetectionResponse.millisecond', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.audio.api.DetectionResponse.keyword', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=635,
)

_AUDIOINFO.fields_by_name['codec'].enum_type = _AUDIOCODEC
_INITSESSIONREQUEST.fields_by_name['user_info'].message_type = _USERINFO
_INITSESSIONREQUEST.fields_by_name['audio_info'].message_type = _AUDIOINFO
_INITSESSIONREQUEST.fields_by_name['persistence_config'].message_type = _PERSISTENCECONFIG
_AUDIODETECTREQUEST.fields_by_name['init'].message_type = _INITSESSIONREQUEST
_AUDIODETECTREQUEST.fields_by_name['audio'].message_type = _AUDIOBLOB
_AUDIODETECTREQUEST.oneofs_by_name['request'].fields.append(
  _AUDIODETECTREQUEST.fields_by_name['init'])
_AUDIODETECTREQUEST.fields_by_name['init'].containing_oneof = _AUDIODETECTREQUEST.oneofs_by_name['request']
_AUDIODETECTREQUEST.oneofs_by_name['request'].fields.append(
  _AUDIODETECTREQUEST.fields_by_name['audio'])
_AUDIODETECTREQUEST.fields_by_name['audio'].containing_oneof = _AUDIODETECTREQUEST.oneofs_by_name['request']
DESCRIPTOR.message_types_by_name['AudioInfo'] = _AUDIOINFO
DESCRIPTOR.message_types_by_name['PersistenceConfig'] = _PERSISTENCECONFIG
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.message_types_by_name['InitSessionRequest'] = _INITSESSIONREQUEST
DESCRIPTOR.message_types_by_name['AudioBlob'] = _AUDIOBLOB
DESCRIPTOR.message_types_by_name['AudioDetectRequest'] = _AUDIODETECTREQUEST
DESCRIPTOR.message_types_by_name['DetectionResponse'] = _DETECTIONRESPONSE
DESCRIPTOR.enum_types_by_name['AudioCodec'] = _AUDIOCODEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioInfo = _reflection.GeneratedProtocolMessageType('AudioInfo', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOINFO,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.AudioInfo)
  ))
_sym_db.RegisterMessage(AudioInfo)

PersistenceConfig = _reflection.GeneratedProtocolMessageType('PersistenceConfig', (_message.Message,), dict(
  DESCRIPTOR = _PERSISTENCECONFIG,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.PersistenceConfig)
  ))
_sym_db.RegisterMessage(PersistenceConfig)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), dict(
  DESCRIPTOR = _USERINFO,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.UserInfo)
  ))
_sym_db.RegisterMessage(UserInfo)

InitSessionRequest = _reflection.GeneratedProtocolMessageType('InitSessionRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITSESSIONREQUEST,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.InitSessionRequest)
  ))
_sym_db.RegisterMessage(InitSessionRequest)

AudioBlob = _reflection.GeneratedProtocolMessageType('AudioBlob', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOBLOB,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.AudioBlob)
  ))
_sym_db.RegisterMessage(AudioBlob)

AudioDetectRequest = _reflection.GeneratedProtocolMessageType('AudioDetectRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIODETECTREQUEST,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.AudioDetectRequest)
  ))
_sym_db.RegisterMessage(AudioDetectRequest)

DetectionResponse = _reflection.GeneratedProtocolMessageType('DetectionResponse', (_message.Message,), dict(
  DESCRIPTOR = _DETECTIONRESPONSE,
  __module__ = 'cogneed_protos.public.audio.audio_api_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.api.DetectionResponse)
  ))
_sym_db.RegisterMessage(DetectionResponse)


DESCRIPTOR._options = None

_STREAMAUDIOSERVICE = _descriptor.ServiceDescriptor(
  name='StreamAudioService',
  full_name='ai.cogneed.audio.api.StreamAudioService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=681,
  serialized_end=804,
  methods=[
  _descriptor.MethodDescriptor(
    name='stream_audio',
    full_name='ai.cogneed.audio.api.StreamAudioService.stream_audio',
    index=0,
    containing_service=None,
    input_type=_AUDIODETECTREQUEST,
    output_type=_DETECTIONRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMAUDIOSERVICE)

DESCRIPTOR.services_by_name['StreamAudioService'] = _STREAMAUDIOSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/predict/predict-api/predict-api-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/predict/predict-api/predict-api-service.proto',
  package='ai.cogneed.api.predict.predictapi',
  syntax='proto3',
  serialized_options=_b('\n!ai.cogneed.api.predict.predictapiP\001'),
  serialized_pb=_b('\n<cogneed-protos/predict/predict-api/predict-api-service.proto\x12!ai.cogneed.api.predict.predictapi\"a\n\x17\x41udioPredictionResponse\x12\x10\n\x08start_ms\x18\x01 \x01(\x03\x12\x0e\n\x06\x65nd_ms\x18\x02 \x01(\x03\x12\x13\n\x0bprobability\x18\x03 \x01(\x01\x12\x0f\n\x07keyword\x18\x04 \x01(\x03\"\x16\n\x14NoPredictionResponse\"\xb1\x01\n\x08Response\x12P\n\nprediction\x18\x01 \x01(\x0b\x32:.ai.cogneed.api.predict.predictapi.AudioPredictionResponseH\x00\x12H\n\x05\x65mpty\x18\x02 \x01(\x0b\x32\x37.ai.cogneed.api.predict.predictapi.NoPredictionResponseH\x00\x42\t\n\x07\x63ontent\"\x88\x01\n\x16\x41udioPredictionRequest\x12\x11\n\tcall_uuid\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\x0c\x12\x12\n\nblob_index\x18\x04 \x01(\x03\x12\x10\n\x08use_case\x18\x05 \x01(\t\x12\r\n\x05major\x18\x06 \x01(\t2\x8b\x01\n\x16\x41udioPredictionService\x12q\n\x07predict\x12\x39.ai.cogneed.api.predict.predictapi.AudioPredictionRequest\x1a+.ai.cogneed.api.predict.predictapi.ResponseB%\n!ai.cogneed.api.predict.predictapiP\x01\x62\x06proto3')
)




_AUDIOPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='AudioPredictionResponse',
  full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_ms', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.start_ms', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_ms', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.end_ms', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probability', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.probability', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionResponse.keyword', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=196,
)


_NOPREDICTIONRESPONSE = _descriptor.Descriptor(
  name='NoPredictionResponse',
  full_name='ai.cogneed.api.predict.predictapi.NoPredictionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=198,
  serialized_end=220,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='ai.cogneed.api.predict.predictapi.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='prediction', full_name='ai.cogneed.api.predict.predictapi.Response.prediction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='ai.cogneed.api.predict.predictapi.Response.empty', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictapi.Response.content',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=223,
  serialized_end=400,
)


_AUDIOPREDICTIONREQUEST = _descriptor.Descriptor(
  name='AudioPredictionRequest',
  full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.call_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model_version', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.model_version', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.content', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.blob_index', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_case', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.use_case', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='major', full_name='ai.cogneed.api.predict.predictapi.AudioPredictionRequest.major', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=539,
)

_RESPONSE.fields_by_name['prediction'].message_type = _AUDIOPREDICTIONRESPONSE
_RESPONSE.fields_by_name['empty'].message_type = _NOPREDICTIONRESPONSE
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['prediction'])
_RESPONSE.fields_by_name['prediction'].containing_oneof = _RESPONSE.oneofs_by_name['content']
_RESPONSE.oneofs_by_name['content'].fields.append(
  _RESPONSE.fields_by_name['empty'])
_RESPONSE.fields_by_name['empty'].containing_oneof = _RESPONSE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['AudioPredictionResponse'] = _AUDIOPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['NoPredictionResponse'] = _NOPREDICTIONRESPONSE
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['AudioPredictionRequest'] = _AUDIOPREDICTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AudioPredictionResponse = _reflection.GeneratedProtocolMessageType('AudioPredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.AudioPredictionResponse)
  ))
_sym_db.RegisterMessage(AudioPredictionResponse)

NoPredictionResponse = _reflection.GeneratedProtocolMessageType('NoPredictionResponse', (_message.Message,), dict(
  DESCRIPTOR = _NOPREDICTIONRESPONSE,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.NoPredictionResponse)
  ))
_sym_db.RegisterMessage(NoPredictionResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), dict(
  DESCRIPTOR = _RESPONSE,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.Response)
  ))
_sym_db.RegisterMessage(Response)

AudioPredictionRequest = _reflection.GeneratedProtocolMessageType('AudioPredictionRequest', (_message.Message,), dict(
  DESCRIPTOR = _AUDIOPREDICTIONREQUEST,
  __module__ = 'cogneed_protos.predict.predict_api.predict_api_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.predict.predictapi.AudioPredictionRequest)
  ))
_sym_db.RegisterMessage(AudioPredictionRequest)


DESCRIPTOR._options = None

_AUDIOPREDICTIONSERVICE = _descriptor.ServiceDescriptor(
  name='AudioPredictionService',
  full_name='ai.cogneed.api.predict.predictapi.AudioPredictionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=542,
  serialized_end=681,
  methods=[
  _descriptor.MethodDescriptor(
    name='predict',
    full_name='ai.cogneed.api.predict.predictapi.AudioPredictionService.predict',
    index=0,
    containing_service=None,
    input_type=_AUDIOPREDICTIONREQUEST,
    output_type=_RESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AUDIOPREDICTIONSERVICE)

DESCRIPTOR.services_by_name['AudioPredictionService'] = _AUDIOPREDICTIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.audio_stream.audio_web_middleware import audio_web_middleware_service_pb2 as cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2
from cogneed_protos.audio_stream.common import common_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2


class WebAudioServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.start = channel.unary_unary(
        '/ai.cogneed.api.audio.web.WebAudioService/start',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.StartWebSessionRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.StartWebSessionResponse.FromString,
        )
    self.audio = channel.unary_unary(
        '/ai.cogneed.api.audio.web.WebAudioService/audio',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.WebAudioRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.StatusResponse.FromString,
        )
    self.subscribe = channel.unary_stream(
        '/ai.cogneed.api.audio.web.WebAudioService/subscribe',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.SubscribeRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.DetectionResponse.FromString,
        )
    self.unstack = channel.unary_unary(
        '/ai.cogneed.api.audio.web.WebAudioService/unstack',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.UnstackRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.UnstackResponse.FromString,
        )


class WebAudioServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def start(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def audio(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def subscribe(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def unstack(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_WebAudioServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'start': grpc.unary_unary_rpc_method_handler(
          servicer.start,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.StartWebSessionRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.StartWebSessionResponse.SerializeToString,
      ),
      'audio': grpc.unary_unary_rpc_method_handler(
          servicer.audio,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.WebAudioRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.StatusResponse.SerializeToString,
      ),
      'subscribe': grpc.unary_stream_rpc_method_handler(
          servicer.subscribe,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.SubscribeRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_common_dot_common__pb2.DetectionResponse.SerializeToString,
      ),
      'unstack': grpc.unary_unary_rpc_method_handler(
          servicer.unstack,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.UnstackRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__web__middleware_dot_audio__web__middleware__service__pb2.UnstackResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.api.audio.web.WebAudioService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/audio-stream/g711-decoder/g711-decoder-service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.audio_stream.common import g711_pb2 as cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/audio-stream/g711-decoder/g711-decoder-service.proto',
  package='ai.cogneed.audio.decode.g711',
  syntax='proto3',
  serialized_options=_b('\n\034ai.cogneed.audio.decode.g711P\001'),
  serialized_pb=_b('\nCcogneed-protos/audio-stream/g711-decoder/g711-decoder-service.proto\x12\x1c\x61i.cogneed.audio.decode.g711\x1a-cogneed-protos/audio-stream/common/g711.proto\"X\n\rDecodeRequest\x12\x36\n\x05\x63odec\x18\x01 \x01(\x0e\x32\'.ai.cogneed.audio.decode.g711.G711Codec\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"!\n\x0e\x44\x65\x63odeResponse\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x32y\n\x12G711DecoderService\x12\x63\n\x06\x64\x65\x63ode\x12+.ai.cogneed.audio.decode.g711.DecodeRequest\x1a,.ai.cogneed.audio.decode.g711.DecodeResponseB \n\x1c\x61i.cogneed.audio.decode.g711P\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2.DESCRIPTOR,])




_DECODEREQUEST = _descriptor.Descriptor(
  name='DecodeRequest',
  full_name='ai.cogneed.audio.decode.g711.DecodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='codec', full_name='ai.cogneed.audio.decode.g711.DecodeRequest.codec', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.audio.decode.g711.DecodeRequest.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=236,
)


_DECODERESPONSE = _descriptor.Descriptor(
  name='DecodeResponse',
  full_name='ai.cogneed.audio.decode.g711.DecodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.audio.decode.g711.DecodeResponse.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=271,
)

_DECODEREQUEST.fields_by_name['codec'].enum_type = cogneed__protos_dot_audio__stream_dot_common_dot_g711__pb2._G711CODEC
DESCRIPTOR.message_types_by_name['DecodeRequest'] = _DECODEREQUEST
DESCRIPTOR.message_types_by_name['DecodeResponse'] = _DECODERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DecodeRequest = _reflection.GeneratedProtocolMessageType('DecodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _DECODEREQUEST,
  __module__ = 'cogneed_protos.audio_stream.g711_decoder.g711_decoder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.decode.g711.DecodeRequest)
  ))
_sym_db.RegisterMessage(DecodeRequest)

DecodeResponse = _reflection.GeneratedProtocolMessageType('DecodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _DECODERESPONSE,
  __module__ = 'cogneed_protos.audio_stream.g711_decoder.g711_decoder_service_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.audio.decode.g711.DecodeResponse)
  ))
_sym_db.RegisterMessage(DecodeResponse)


DESCRIPTOR._options = None

_G711DECODERSERVICE = _descriptor.ServiceDescriptor(
  name='G711DecoderService',
  full_name='ai.cogneed.audio.decode.g711.G711DecoderService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=273,
  serialized_end=394,
  methods=[
  _descriptor.MethodDescriptor(
    name='decode',
    full_name='ai.cogneed.audio.decode.g711.G711DecoderService.decode',
    index=0,
    containing_service=None,
    input_type=_DECODEREQUEST,
    output_type=_DECODERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_G711DECODERSERVICE)

DESCRIPTOR.services_by_name['G711DecoderService'] = _G711DECODERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.audio_stream.audio_stream_recorder import audio_stream_recorder_service_pb2 as cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2


class RecordServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.record = channel.unary_unary(
        '/ai.cogneed.record.v1.RecordService/record',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.RecordRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.FromString,
        )
    self.consolidate = channel.unary_unary(
        '/ai.cogneed.record.v1.RecordService/consolidate',
        request_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.ConsolidateRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.FromString,
        )


class RecordServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def record(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def consolidate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RecordServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'record': grpc.unary_unary_rpc_method_handler(
          servicer.record,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.RecordRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.SerializeToString,
      ),
      'consolidate': grpc.unary_unary_rpc_method_handler(
          servicer.consolidate,
          request_deserializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.ConsolidateRequest.FromString,
          response_serializer=cogneed__protos_dot_audio__stream_dot_audio__stream__recorder_dot_audio__stream__recorder__service__pb2.Response.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.record.v1.RecordService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
